Index: Source/core/html/HTMLFrameOwnerElement.h |
diff --git a/Source/core/html/HTMLFrameOwnerElement.h b/Source/core/html/HTMLFrameOwnerElement.h |
index 349e194eae322dd95b6f681cc0ca38f66f36a2ea..960adeb67ddde2b7ba6b934e94ac53ba0b054b2f 100644 |
--- a/Source/core/html/HTMLFrameOwnerElement.h |
+++ b/Source/core/html/HTMLFrameOwnerElement.h |
@@ -33,7 +33,7 @@ namespace blink { |
class LocalDOMWindow; |
class ExceptionState; |
class Frame; |
-class RenderPart; |
+class LayoutPart; |
class Widget; |
class HTMLFrameOwnerElement : public HTMLElement, public FrameOwner { |
@@ -50,10 +50,10 @@ public: |
virtual void disconnectContentFrame(); |
// Most subclasses use RenderPart (either RenderEmbeddedObject or RenderIFrame) |
// except for HTMLObjectElement and HTMLEmbedElement which may return any |
// LayoutObject when using fallback content. |
- RenderPart* renderPart() const; |
+ LayoutPart* layoutPart() const; |
Document* getSVGDocument(ExceptionState&) const; |
@@ -50,10 +50,10 @@ public: |
virtual void disconnectContentFrame(); |
- // Most subclasses use RenderPart (either RenderEmbeddedObject or RenderIFrame) |
+ // Most subclasses use LayoutPart (either RenderEmbeddedObject or RenderIFrame) |
// except for HTMLObjectElement and HTMLEmbedElement which may return any |
// LayoutObject when using fallback content. |